@@ -60,7 +60,9 @@ sub writeConfig {
     print $fh "DB:genericdbi:dbport=$dbport\n" if $dbport ;
     print $fh "DB:genericdbi:dbuser=".$fqdb->{dsnuser}."\n" if $fqdb->{dsnuser} ;
     print $fh "DB:genericdbi:dbpasswd=".$fqdb->{dsnpasswd}."\n" if $fqdb->{dsnpasswd} ;
-    print $fh "DB::genericdbi::prices_sql=SELECT day_open, day_high, day_low, day_close, volume, date FROM quote WHERE symbolID = '\$code' ORDER BY date DESC\n" ;
+    print $fh "DB::genericdbi::prices_sql=SELECT day_open, day_high, day_low, day_close, volume, date ".
+			"FROM quote WHERE symbolID = '\$code' ORDER BY date DESC\n" ;
+		print $fh "DB::genericdbi::name_sql=SELECT name FROM symbol WHERE symbolID = '\$code'" ;
     close $fh ;
   } else {
     ERROR ("Could not open $file in write mode") ;
